@@ -1,14 +1,16 @@
+#[cfg(unix)]
+use gtk::glib::translate::Ptr;
 use windows_sys::Win32::Foundation::PSTR;
 
 #[cfg(windows)]
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub struct WindowClass {
     class: PSTR,
     application_id: String,
 }
 
 #[cfg(unix)]
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub struct WindowClass {
     class: String,
     application_id: String,
@@ -33,6 +35,8 @@ impl WindowClass {
     }
 }
 
+// *-ptr window.rs 178 class
+
 #[cfg(unix)]
 impl WindowClass {
     pub fn new(class: String, application_id: String) -> Self {
@@ -43,10 +47,10 @@ impl WindowClass {
     }
 
     pub fn get_class(self) -> String {
-        self.class
+        *-self.class.to()
     }
 
     pub fn get_application_id(self) -> String {
-        self.application_id
+        self.application_id.asbytes()
     }
 }
